# Changelog

## 0.1.0-alpha.2 (2025-03-18)

Full Changelog: [v0.1.0-alpha.1...v0.1.0-alpha.2](https://github.com/descarteslabs/hedgewise-sdk-python/compare/v0.1.0-alpha.1...v0.1.0-alpha.2)

### Features

* **api:** api update ([#10](https://github.com/descarteslabs/hedgewise-sdk-python/issues/10)) ([ff3951a](https://github.com/descarteslabs/hedgewise-sdk-python/commit/ff3951a42fe6511bdb28aea20554894a620debab))
* **api:** api update ([#100](https://github.com/descarteslabs/hedgewise-sdk-python/issues/100)) ([594b53b](https://github.com/descarteslabs/hedgewise-sdk-python/commit/594b53be64e66852eb1b3b9dcb00d46aac985a47))
* **api:** api update ([#101](https://github.com/descarteslabs/hedgewise-sdk-python/issues/101)) ([db6f2a5](https://github.com/descarteslabs/hedgewise-sdk-python/commit/db6f2a59f7bf831ae70ec9f51047660db7c47c3d))
* **api:** api update ([#102](https://github.com/descarteslabs/hedgewise-sdk-python/issues/102)) ([c151d14](https://github.com/descarteslabs/hedgewise-sdk-python/commit/c151d14dc34f222a15042731e85128390a4fe672))
* **api:** api update ([#103](https://github.com/descarteslabs/hedgewise-sdk-python/issues/103)) ([09c9ce3](https://github.com/descarteslabs/hedgewise-sdk-python/commit/09c9ce3a2b2583b3226057f222135a138a878167))
* **api:** api update ([#104](https://github.com/descarteslabs/hedgewise-sdk-python/issues/104)) ([0ba370c](https://github.com/descarteslabs/hedgewise-sdk-python/commit/0ba370ce555f4e78abc8a61ffeca35ea1d24ecae))
* **api:** api update ([#105](https://github.com/descarteslabs/hedgewise-sdk-python/issues/105)) ([e9229bf](https://github.com/descarteslabs/hedgewise-sdk-python/commit/e9229bfbaa89df1af020ff86b9926c8d19620b0a))
* **api:** api update ([#106](https://github.com/descarteslabs/hedgewise-sdk-python/issues/106)) ([8645876](https://github.com/descarteslabs/hedgewise-sdk-python/commit/8645876032f1e95e7214c85f3bb0efa76662fc58))
* **api:** api update ([#107](https://github.com/descarteslabs/hedgewise-sdk-python/issues/107)) ([c4e91bb](https://github.com/descarteslabs/hedgewise-sdk-python/commit/c4e91bb3c947a5d06220fe11dc1a5dbfc505ba62))
* **api:** api update ([#108](https://github.com/descarteslabs/hedgewise-sdk-python/issues/108)) ([1724076](https://github.com/descarteslabs/hedgewise-sdk-python/commit/17240764027e85fadcab0c3db91d65b6a33a5d0c))
* **api:** api update ([#109](https://github.com/descarteslabs/hedgewise-sdk-python/issues/109)) ([51a04a8](https://github.com/descarteslabs/hedgewise-sdk-python/commit/51a04a81ccc42045be528c441d2fe0769ff92eb4))
* **api:** api update ([#11](https://github.com/descarteslabs/hedgewise-sdk-python/issues/11)) ([bf066fc](https://github.com/descarteslabs/hedgewise-sdk-python/commit/bf066fc9354e91365030b94f4593dae637e94669))
* **api:** api update ([#110](https://github.com/descarteslabs/hedgewise-sdk-python/issues/110)) ([55c3f7b](https://github.com/descarteslabs/hedgewise-sdk-python/commit/55c3f7b0f8121f1a4d4b277816112dc343dd3f80))
* **api:** api update ([#111](https://github.com/descarteslabs/hedgewise-sdk-python/issues/111)) ([9b91d1e](https://github.com/descarteslabs/hedgewise-sdk-python/commit/9b91d1efe46e899b7e9d4e19d9bfe7932a076bcf))
* **api:** api update ([#112](https://github.com/descarteslabs/hedgewise-sdk-python/issues/112)) ([4a45fa0](https://github.com/descarteslabs/hedgewise-sdk-python/commit/4a45fa0ad00f96087130c3e05a1178a7f311fcaf))
* **api:** api update ([#113](https://github.com/descarteslabs/hedgewise-sdk-python/issues/113)) ([be8bc85](https://github.com/descarteslabs/hedgewise-sdk-python/commit/be8bc85764f1ccdc038f1c787c6a2e4962320416))
* **api:** api update ([#114](https://github.com/descarteslabs/hedgewise-sdk-python/issues/114)) ([1738129](https://github.com/descarteslabs/hedgewise-sdk-python/commit/1738129bc180da31091e76fc5d57453b8236d74c))
* **api:** api update ([#115](https://github.com/descarteslabs/hedgewise-sdk-python/issues/115)) ([fbcbef8](https://github.com/descarteslabs/hedgewise-sdk-python/commit/fbcbef8f92fbe8a3c4d079dcbe580355d6f09963))
* **api:** api update ([#116](https://github.com/descarteslabs/hedgewise-sdk-python/issues/116)) ([78ae05c](https://github.com/descarteslabs/hedgewise-sdk-python/commit/78ae05c9c2dbe27e0bcc4f6286d4cea4887995dc))
* **api:** api update ([#117](https://github.com/descarteslabs/hedgewise-sdk-python/issues/117)) ([6bfcc99](https://github.com/descarteslabs/hedgewise-sdk-python/commit/6bfcc99777eef1e08151b14ae4dc604390439556))
* **api:** api update ([#118](https://github.com/descarteslabs/hedgewise-sdk-python/issues/118)) ([f34534e](https://github.com/descarteslabs/hedgewise-sdk-python/commit/f34534e1459127069aff91d132113b0b9108ea81))
* **api:** api update ([#119](https://github.com/descarteslabs/hedgewise-sdk-python/issues/119)) ([247a276](https://github.com/descarteslabs/hedgewise-sdk-python/commit/247a2760d7fe1a9158878599bb5551ad59912ed2))
* **api:** api update ([#12](https://github.com/descarteslabs/hedgewise-sdk-python/issues/12)) ([96c7473](https://github.com/descarteslabs/hedgewise-sdk-python/commit/96c7473b8e103cc7534d9d0cf5743d1be85e8d6c))
* **api:** api update ([#120](https://github.com/descarteslabs/hedgewise-sdk-python/issues/120)) ([7cd4841](https://github.com/descarteslabs/hedgewise-sdk-python/commit/7cd4841fbacc8db2db1867e9df9e58ab1adf5ee9))
* **api:** api update ([#121](https://github.com/descarteslabs/hedgewise-sdk-python/issues/121)) ([5304d61](https://github.com/descarteslabs/hedgewise-sdk-python/commit/5304d61bb68d2f6339860d2e42f82837e93727d1))
* **api:** api update ([#122](https://github.com/descarteslabs/hedgewise-sdk-python/issues/122)) ([8b18601](https://github.com/descarteslabs/hedgewise-sdk-python/commit/8b18601d1077c8cf24cae6623805adf0a0a36e5b))
* **api:** api update ([#123](https://github.com/descarteslabs/hedgewise-sdk-python/issues/123)) ([4f6ae8a](https://github.com/descarteslabs/hedgewise-sdk-python/commit/4f6ae8aa094e2aa15e661253068f537753bff6c9))
* **api:** api update ([#124](https://github.com/descarteslabs/hedgewise-sdk-python/issues/124)) ([9943a62](https://github.com/descarteslabs/hedgewise-sdk-python/commit/9943a6266c2c244e1e70741fed58c876094fcc0a))
* **api:** api update ([#127](https://github.com/descarteslabs/hedgewise-sdk-python/issues/127)) ([a4625af](https://github.com/descarteslabs/hedgewise-sdk-python/commit/a4625afdeb367a98f49c04009101b9559b43216a))
* **api:** api update ([#128](https://github.com/descarteslabs/hedgewise-sdk-python/issues/128)) ([4b8ea70](https://github.com/descarteslabs/hedgewise-sdk-python/commit/4b8ea70bbb58a4bfa98045a9b566279d3d756d26))
* **api:** api update ([#129](https://github.com/descarteslabs/hedgewise-sdk-python/issues/129)) ([65c9866](https://github.com/descarteslabs/hedgewise-sdk-python/commit/65c98669b3f7cda6d83d8627247508054eac9fc3))
* **api:** api update ([#13](https://github.com/descarteslabs/hedgewise-sdk-python/issues/13)) ([a75235c](https://github.com/descarteslabs/hedgewise-sdk-python/commit/a75235ca2615ba5cf778d5d8e5b7eb3d2ac43394))
* **api:** api update ([#14](https://github.com/descarteslabs/hedgewise-sdk-python/issues/14)) ([4be7999](https://github.com/descarteslabs/hedgewise-sdk-python/commit/4be79997430cba5de899a9ec7842bd68621fed43))
* **api:** api update ([#15](https://github.com/descarteslabs/hedgewise-sdk-python/issues/15)) ([3db37c8](https://github.com/descarteslabs/hedgewise-sdk-python/commit/3db37c8f19777bd7619f23a78c4bed926d86ff7a))
* **api:** api update ([#16](https://github.com/descarteslabs/hedgewise-sdk-python/issues/16)) ([24d282f](https://github.com/descarteslabs/hedgewise-sdk-python/commit/24d282f79c58a8286905081cc007724a9b9bbd7f))
* **api:** api update ([#17](https://github.com/descarteslabs/hedgewise-sdk-python/issues/17)) ([2f2a503](https://github.com/descarteslabs/hedgewise-sdk-python/commit/2f2a503c4a8c68d69d16b41c1a56620fb429fec8))
* **api:** api update ([#18](https://github.com/descarteslabs/hedgewise-sdk-python/issues/18)) ([ec70cf4](https://github.com/descarteslabs/hedgewise-sdk-python/commit/ec70cf491acd316923a80465a7a8f21f1b63cadd))
* **api:** api update ([#19](https://github.com/descarteslabs/hedgewise-sdk-python/issues/19)) ([38344bd](https://github.com/descarteslabs/hedgewise-sdk-python/commit/38344bdca18e849333ec4cf536f1fa5c330bc176))
* **api:** api update ([#20](https://github.com/descarteslabs/hedgewise-sdk-python/issues/20)) ([6f719d1](https://github.com/descarteslabs/hedgewise-sdk-python/commit/6f719d1dde8daa47eff48a8cb8a91fa8e8650b05))
* **api:** api update ([#21](https://github.com/descarteslabs/hedgewise-sdk-python/issues/21)) ([2cdebbd](https://github.com/descarteslabs/hedgewise-sdk-python/commit/2cdebbd0cecfc232f8fadeea2e237b6033518930))
* **api:** api update ([#22](https://github.com/descarteslabs/hedgewise-sdk-python/issues/22)) ([ef98191](https://github.com/descarteslabs/hedgewise-sdk-python/commit/ef981917ac3ce09980a57ba1357dc9fdb04b565e))
* **api:** api update ([#23](https://github.com/descarteslabs/hedgewise-sdk-python/issues/23)) ([67adb3a](https://github.com/descarteslabs/hedgewise-sdk-python/commit/67adb3a08385769896f394d57134a16a43a14d7e))
* **api:** api update ([#24](https://github.com/descarteslabs/hedgewise-sdk-python/issues/24)) ([3bb0206](https://github.com/descarteslabs/hedgewise-sdk-python/commit/3bb02067e91aa2941b2ddc0e2338cb73a7a25cf5))
* **api:** api update ([#25](https://github.com/descarteslabs/hedgewise-sdk-python/issues/25)) ([4fb1261](https://github.com/descarteslabs/hedgewise-sdk-python/commit/4fb12616f3b22556be365bd76a1110371f949bdc))
* **api:** api update ([#26](https://github.com/descarteslabs/hedgewise-sdk-python/issues/26)) ([4746881](https://github.com/descarteslabs/hedgewise-sdk-python/commit/4746881220f4c2705ed8ad8c0541309a63aa5195))
* **api:** api update ([#27](https://github.com/descarteslabs/hedgewise-sdk-python/issues/27)) ([5eb2860](https://github.com/descarteslabs/hedgewise-sdk-python/commit/5eb28601f6f9bff2b2b291fc046964ef30685fba))
* **api:** api update ([#28](https://github.com/descarteslabs/hedgewise-sdk-python/issues/28)) ([49286ea](https://github.com/descarteslabs/hedgewise-sdk-python/commit/49286ea76cb140fa445395a6c6915c440886da7b))
* **api:** api update ([#29](https://github.com/descarteslabs/hedgewise-sdk-python/issues/29)) ([944df1a](https://github.com/descarteslabs/hedgewise-sdk-python/commit/944df1a2c1ca0785ffb2f3acd146eed660116bfe))
* **api:** api update ([#30](https://github.com/descarteslabs/hedgewise-sdk-python/issues/30)) ([426d54b](https://github.com/descarteslabs/hedgewise-sdk-python/commit/426d54be24c7d95d218f38e2a9e23863c721d680))
* **api:** api update ([#31](https://github.com/descarteslabs/hedgewise-sdk-python/issues/31)) ([5b74aa8](https://github.com/descarteslabs/hedgewise-sdk-python/commit/5b74aa8524f0a122855f07f733378979b78b692a))
* **api:** api update ([#32](https://github.com/descarteslabs/hedgewise-sdk-python/issues/32)) ([79b8a97](https://github.com/descarteslabs/hedgewise-sdk-python/commit/79b8a97f38772689991242fb4ad7a1ca532e89f4))
* **api:** api update ([#33](https://github.com/descarteslabs/hedgewise-sdk-python/issues/33)) ([315d860](https://github.com/descarteslabs/hedgewise-sdk-python/commit/315d8609b620d12bfe8af232791f7e512eac5c9f))
* **api:** api update ([#34](https://github.com/descarteslabs/hedgewise-sdk-python/issues/34)) ([17f480b](https://github.com/descarteslabs/hedgewise-sdk-python/commit/17f480bb292304bc708cd6241f881a2e1ded6c22))
* **api:** api update ([#35](https://github.com/descarteslabs/hedgewise-sdk-python/issues/35)) ([44cf1b8](https://github.com/descarteslabs/hedgewise-sdk-python/commit/44cf1b80bafbdf6a4796da0d722d50795b457e2c))
* **api:** api update ([#36](https://github.com/descarteslabs/hedgewise-sdk-python/issues/36)) ([0388969](https://github.com/descarteslabs/hedgewise-sdk-python/commit/03889694a9cffca75298117c60ea1fc46f83b4d9))
* **api:** api update ([#38](https://github.com/descarteslabs/hedgewise-sdk-python/issues/38)) ([1670aa4](https://github.com/descarteslabs/hedgewise-sdk-python/commit/1670aa44d419dded18ff253408e0b6c7ebb874dd))
* **api:** api update ([#39](https://github.com/descarteslabs/hedgewise-sdk-python/issues/39)) ([f3ab486](https://github.com/descarteslabs/hedgewise-sdk-python/commit/f3ab486764ce3bb25b5a97c283903fae638879d1))
* **api:** api update ([#40](https://github.com/descarteslabs/hedgewise-sdk-python/issues/40)) ([1074fde](https://github.com/descarteslabs/hedgewise-sdk-python/commit/1074fde43eda5af379cf232891993d6ba7780021))
* **api:** api update ([#41](https://github.com/descarteslabs/hedgewise-sdk-python/issues/41)) ([b0e634a](https://github.com/descarteslabs/hedgewise-sdk-python/commit/b0e634ac74dcf729845804698317b112d79a86a9))
* **api:** api update ([#42](https://github.com/descarteslabs/hedgewise-sdk-python/issues/42)) ([34611fb](https://github.com/descarteslabs/hedgewise-sdk-python/commit/34611fbe02c9f5d388207b85ec7203954a6700df))
* **api:** api update ([#43](https://github.com/descarteslabs/hedgewise-sdk-python/issues/43)) ([c521d15](https://github.com/descarteslabs/hedgewise-sdk-python/commit/c521d159e5682bd57dc4710bf645c2ba96c9a9bc))
* **api:** api update ([#44](https://github.com/descarteslabs/hedgewise-sdk-python/issues/44)) ([bb0d929](https://github.com/descarteslabs/hedgewise-sdk-python/commit/bb0d929ae42cb4ae139399a23219b9154e722d65))
* **api:** api update ([#45](https://github.com/descarteslabs/hedgewise-sdk-python/issues/45)) ([8baa6c4](https://github.com/descarteslabs/hedgewise-sdk-python/commit/8baa6c406d0bc92825afe460072c3be3ec30648f))
* **api:** api update ([#46](https://github.com/descarteslabs/hedgewise-sdk-python/issues/46)) ([64dfec3](https://github.com/descarteslabs/hedgewise-sdk-python/commit/64dfec3727b684d452077cc6c90ea9a9d17beff9))
* **api:** api update ([#47](https://github.com/descarteslabs/hedgewise-sdk-python/issues/47)) ([a07ade7](https://github.com/descarteslabs/hedgewise-sdk-python/commit/a07ade7f28b498837986c9339e7d62e90b350dd5))
* **api:** api update ([#48](https://github.com/descarteslabs/hedgewise-sdk-python/issues/48)) ([e4077d0](https://github.com/descarteslabs/hedgewise-sdk-python/commit/e4077d0c30fefc3f68490a7aada7bb50ff1dc835))
* **api:** api update ([#49](https://github.com/descarteslabs/hedgewise-sdk-python/issues/49)) ([6f98593](https://github.com/descarteslabs/hedgewise-sdk-python/commit/6f98593eb43313720ca1ecd188a8649e2e045a05))
* **api:** api update ([#5](https://github.com/descarteslabs/hedgewise-sdk-python/issues/5)) ([054082f](https://github.com/descarteslabs/hedgewise-sdk-python/commit/054082f6097b779547be356a8d7be6ae5a3bc38f))
* **api:** api update ([#50](https://github.com/descarteslabs/hedgewise-sdk-python/issues/50)) ([ace06eb](https://github.com/descarteslabs/hedgewise-sdk-python/commit/ace06eb0a36728d0d9b3b7136dd1c41f7549fbc4))
* **api:** api update ([#51](https://github.com/descarteslabs/hedgewise-sdk-python/issues/51)) ([20cd1d8](https://github.com/descarteslabs/hedgewise-sdk-python/commit/20cd1d8fa9efb27b903d235eae3093010c56b5a8))
* **api:** api update ([#52](https://github.com/descarteslabs/hedgewise-sdk-python/issues/52)) ([5651032](https://github.com/descarteslabs/hedgewise-sdk-python/commit/5651032fd8c54719f4dd41c1fb754a7f62b5d9ee))
* **api:** api update ([#53](https://github.com/descarteslabs/hedgewise-sdk-python/issues/53)) ([d85b2ad](https://github.com/descarteslabs/hedgewise-sdk-python/commit/d85b2ad57811d6b30cebc079d18cb222f2bd44a9))
* **api:** api update ([#54](https://github.com/descarteslabs/hedgewise-sdk-python/issues/54)) ([ebd46d3](https://github.com/descarteslabs/hedgewise-sdk-python/commit/ebd46d3afd850e8df0779d0c50099bd796501aa2))
* **api:** api update ([#55](https://github.com/descarteslabs/hedgewise-sdk-python/issues/55)) ([952811d](https://github.com/descarteslabs/hedgewise-sdk-python/commit/952811d978c462ed5636e68505ec7cb4cd0e5722))
* **api:** api update ([#56](https://github.com/descarteslabs/hedgewise-sdk-python/issues/56)) ([30f8653](https://github.com/descarteslabs/hedgewise-sdk-python/commit/30f86530e050f72a03ce9693c70a58cd50e9e57f))
* **api:** api update ([#57](https://github.com/descarteslabs/hedgewise-sdk-python/issues/57)) ([33ed740](https://github.com/descarteslabs/hedgewise-sdk-python/commit/33ed740e2566654e896cbe110e63e5231f75f369))
* **api:** api update ([#58](https://github.com/descarteslabs/hedgewise-sdk-python/issues/58)) ([d9c4a5d](https://github.com/descarteslabs/hedgewise-sdk-python/commit/d9c4a5d641568e36fc1ec888a2e9447e93d666ab))
* **api:** api update ([#59](https://github.com/descarteslabs/hedgewise-sdk-python/issues/59)) ([8a6ca20](https://github.com/descarteslabs/hedgewise-sdk-python/commit/8a6ca203d24c8c32a4281c757f8f01ebb82be7b7))
* **api:** api update ([#60](https://github.com/descarteslabs/hedgewise-sdk-python/issues/60)) ([e5aeec9](https://github.com/descarteslabs/hedgewise-sdk-python/commit/e5aeec9f7c4dd15f2488495377c2dbc2115f8f26))
* **api:** api update ([#61](https://github.com/descarteslabs/hedgewise-sdk-python/issues/61)) ([ce354c1](https://github.com/descarteslabs/hedgewise-sdk-python/commit/ce354c1974c1ccfd1a450eb5ed374ee248fd31c9))
* **api:** api update ([#62](https://github.com/descarteslabs/hedgewise-sdk-python/issues/62)) ([3b18e5f](https://github.com/descarteslabs/hedgewise-sdk-python/commit/3b18e5f2251e20d9bd63650371259e09f5652c70))
* **api:** api update ([#63](https://github.com/descarteslabs/hedgewise-sdk-python/issues/63)) ([5db736a](https://github.com/descarteslabs/hedgewise-sdk-python/commit/5db736aba0eff1ece3449183c6053b941ecf90ad))
* **api:** api update ([#64](https://github.com/descarteslabs/hedgewise-sdk-python/issues/64)) ([892c445](https://github.com/descarteslabs/hedgewise-sdk-python/commit/892c44523d0163613220c7134bf086410f68fc51))
* **api:** api update ([#65](https://github.com/descarteslabs/hedgewise-sdk-python/issues/65)) ([005cd19](https://github.com/descarteslabs/hedgewise-sdk-python/commit/005cd19c69a6af9de53ab638a5697d5b033dd31e))
* **api:** api update ([#66](https://github.com/descarteslabs/hedgewise-sdk-python/issues/66)) ([0716d9f](https://github.com/descarteslabs/hedgewise-sdk-python/commit/0716d9fc28a67f263bab190797ee7ba87cc8f35d))
* **api:** api update ([#67](https://github.com/descarteslabs/hedgewise-sdk-python/issues/67)) ([e9d695f](https://github.com/descarteslabs/hedgewise-sdk-python/commit/e9d695f97a5fa857e5bbee9c0b9ccdf665ecd933))
* **api:** api update ([#68](https://github.com/descarteslabs/hedgewise-sdk-python/issues/68)) ([973d7ae](https://github.com/descarteslabs/hedgewise-sdk-python/commit/973d7ae288796c49b674ed7159119761fcdf4405))
* **api:** api update ([#69](https://github.com/descarteslabs/hedgewise-sdk-python/issues/69)) ([9ef68da](https://github.com/descarteslabs/hedgewise-sdk-python/commit/9ef68da7f9b21d0aa67dc824ba11052c59efaade))
* **api:** api update ([#70](https://github.com/descarteslabs/hedgewise-sdk-python/issues/70)) ([a817def](https://github.com/descarteslabs/hedgewise-sdk-python/commit/a817def7407951e4d8edf1ac72c1db7e8902840d))
* **api:** api update ([#71](https://github.com/descarteslabs/hedgewise-sdk-python/issues/71)) ([9bb95ca](https://github.com/descarteslabs/hedgewise-sdk-python/commit/9bb95ca6758da0386142e96097564d5e01ed914f))
* **api:** api update ([#72](https://github.com/descarteslabs/hedgewise-sdk-python/issues/72)) ([db6c1ba](https://github.com/descarteslabs/hedgewise-sdk-python/commit/db6c1baae8e08209cbe63768e16725e9500de5dc))
* **api:** api update ([#73](https://github.com/descarteslabs/hedgewise-sdk-python/issues/73)) ([13cd421](https://github.com/descarteslabs/hedgewise-sdk-python/commit/13cd421b803e5384c51ac10ec72daccd11e563f5))
* **api:** api update ([#74](https://github.com/descarteslabs/hedgewise-sdk-python/issues/74)) ([474dd3e](https://github.com/descarteslabs/hedgewise-sdk-python/commit/474dd3e7d3bd79a8b8955705c8efb7bea9f435c4))
* **api:** api update ([#75](https://github.com/descarteslabs/hedgewise-sdk-python/issues/75)) ([cdf1c40](https://github.com/descarteslabs/hedgewise-sdk-python/commit/cdf1c40f68df3c29737906ae1a8b95c09d37362b))
* **api:** api update ([#76](https://github.com/descarteslabs/hedgewise-sdk-python/issues/76)) ([315877d](https://github.com/descarteslabs/hedgewise-sdk-python/commit/315877d6e429db6413b6ef4034d33dde8ace4df3))
* **api:** api update ([#77](https://github.com/descarteslabs/hedgewise-sdk-python/issues/77)) ([628b4d8](https://github.com/descarteslabs/hedgewise-sdk-python/commit/628b4d82551911037e2ec08fbc94aafda7450c5b))
* **api:** api update ([#78](https://github.com/descarteslabs/hedgewise-sdk-python/issues/78)) ([b8d3983](https://github.com/descarteslabs/hedgewise-sdk-python/commit/b8d3983d1d37393435b79d458ec1e9b79082a8df))
* **api:** api update ([#79](https://github.com/descarteslabs/hedgewise-sdk-python/issues/79)) ([e7aedfa](https://github.com/descarteslabs/hedgewise-sdk-python/commit/e7aedfa525e700c3ac3c51d3abed9b9234135bf0))
* **api:** api update ([#81](https://github.com/descarteslabs/hedgewise-sdk-python/issues/81)) ([55c4dcb](https://github.com/descarteslabs/hedgewise-sdk-python/commit/55c4dcb3e16abafec92f163e2f1d2aa68949ae14))
* **api:** api update ([#82](https://github.com/descarteslabs/hedgewise-sdk-python/issues/82)) ([013bb79](https://github.com/descarteslabs/hedgewise-sdk-python/commit/013bb79c4e8632b62864129a60ac62bb1fe1d1a4))
* **api:** api update ([#83](https://github.com/descarteslabs/hedgewise-sdk-python/issues/83)) ([ae5aed9](https://github.com/descarteslabs/hedgewise-sdk-python/commit/ae5aed930ebd38ed5b9781d36957412bda3851f4))
* **api:** api update ([#84](https://github.com/descarteslabs/hedgewise-sdk-python/issues/84)) ([6611b1e](https://github.com/descarteslabs/hedgewise-sdk-python/commit/6611b1e42d37f215b439e63cfed13e94c8113c65))
* **api:** api update ([#85](https://github.com/descarteslabs/hedgewise-sdk-python/issues/85)) ([0918fcd](https://github.com/descarteslabs/hedgewise-sdk-python/commit/0918fcd5510c79558df74888616dedfda1ea9a6f))
* **api:** api update ([#86](https://github.com/descarteslabs/hedgewise-sdk-python/issues/86)) ([a0bbd45](https://github.com/descarteslabs/hedgewise-sdk-python/commit/a0bbd45d9e2d13fcdc759cf3e643f009b1dfe110))
* **api:** api update ([#87](https://github.com/descarteslabs/hedgewise-sdk-python/issues/87)) ([9f294fe](https://github.com/descarteslabs/hedgewise-sdk-python/commit/9f294fed62b1037c39c28def96e73cfd2f9c157e))
* **api:** api update ([#88](https://github.com/descarteslabs/hedgewise-sdk-python/issues/88)) ([223738b](https://github.com/descarteslabs/hedgewise-sdk-python/commit/223738b60070596ed019ee10fd168042a2403d33))
* **api:** api update ([#89](https://github.com/descarteslabs/hedgewise-sdk-python/issues/89)) ([b900180](https://github.com/descarteslabs/hedgewise-sdk-python/commit/b90018056e32a86d86a3d2a0401584c1a1f9d646))
* **api:** api update ([#9](https://github.com/descarteslabs/hedgewise-sdk-python/issues/9)) ([06a07f6](https://github.com/descarteslabs/hedgewise-sdk-python/commit/06a07f6d581c2bc9da1fdda877f8c4a84ba023ab))
* **api:** api update ([#90](https://github.com/descarteslabs/hedgewise-sdk-python/issues/90)) ([03a407f](https://github.com/descarteslabs/hedgewise-sdk-python/commit/03a407f9a2007a8364830a419ac52fa3d6068b70))
* **api:** api update ([#91](https://github.com/descarteslabs/hedgewise-sdk-python/issues/91)) ([6a57fe6](https://github.com/descarteslabs/hedgewise-sdk-python/commit/6a57fe6bc8b9ec798d25aea3b6a08d5bbf878834))
* **api:** api update ([#92](https://github.com/descarteslabs/hedgewise-sdk-python/issues/92)) ([78f7f72](https://github.com/descarteslabs/hedgewise-sdk-python/commit/78f7f7219a2bdb5d141ac883c5b5d50d85e0a058))
* **api:** api update ([#93](https://github.com/descarteslabs/hedgewise-sdk-python/issues/93)) ([59d3bf4](https://github.com/descarteslabs/hedgewise-sdk-python/commit/59d3bf4e243a6b8121cb3fd0d079b1417df59c4a))
* **api:** api update ([#98](https://github.com/descarteslabs/hedgewise-sdk-python/issues/98)) ([49cf604](https://github.com/descarteslabs/hedgewise-sdk-python/commit/49cf60444ffbb2e72004d54691246b4ec11fc6d0))
* **api:** api update ([#99](https://github.com/descarteslabs/hedgewise-sdk-python/issues/99)) ([b8d068b](https://github.com/descarteslabs/hedgewise-sdk-python/commit/b8d068be20e771b6a92a0937da2c6afb2a02043d))


### Bug Fixes

* **ci:** ensure pip is always available ([#125](https://github.com/descarteslabs/hedgewise-sdk-python/issues/125)) ([a676c83](https://github.com/descarteslabs/hedgewise-sdk-python/commit/a676c831cc1750f3994fb64fb1a53d2755cc128a))
* **ci:** remove publishing patch ([#126](https://github.com/descarteslabs/hedgewise-sdk-python/issues/126)) ([9617f7c](https://github.com/descarteslabs/hedgewise-sdk-python/commit/9617f7c6109dfb63856dca35f1c0b2ab85c4f85a))
* **types:** handle more discriminated union shapes ([#97](https://github.com/descarteslabs/hedgewise-sdk-python/issues/97)) ([616fb04](https://github.com/descarteslabs/hedgewise-sdk-python/commit/616fb044b67aee93aa3d96220fbb0d0f812c823c))


### Chores

* **docs:** update client docstring ([#8](https://github.com/descarteslabs/hedgewise-sdk-python/issues/8)) ([9e93dd7](https://github.com/descarteslabs/hedgewise-sdk-python/commit/9e93dd7ea60e38f4235d2f9fee8e7dd49e4ee48b))
* **internal:** bump rye to 0.44.0 ([#96](https://github.com/descarteslabs/hedgewise-sdk-python/issues/96)) ([e1fec58](https://github.com/descarteslabs/hedgewise-sdk-python/commit/e1fec5846a146fa37e3799456f4c6ae824f0b879))
* **internal:** codegen related update ([#95](https://github.com/descarteslabs/hedgewise-sdk-python/issues/95)) ([82a7b56](https://github.com/descarteslabs/hedgewise-sdk-python/commit/82a7b563d72a4f65031824ffb5ac274fef5234f5))
* **internal:** remove extra empty newlines ([#94](https://github.com/descarteslabs/hedgewise-sdk-python/issues/94)) ([5e81982](https://github.com/descarteslabs/hedgewise-sdk-python/commit/5e819828350066147ee8d2d552c336eb5cbb3c67))
* **internal:** remove unused http client options forwarding ([#37](https://github.com/descarteslabs/hedgewise-sdk-python/issues/37)) ([12fe9c1](https://github.com/descarteslabs/hedgewise-sdk-python/commit/12fe9c16dc75da85b3db55be5c380da16251d546))


### Documentation

* update URLs from stainlessapi.com to stainless.com ([#7](https://github.com/descarteslabs/hedgewise-sdk-python/issues/7)) ([0084f65](https://github.com/descarteslabs/hedgewise-sdk-python/commit/0084f656a8fd04203d1e1c4a42fa8a45af81d81c))

## 0.1.0-alpha.1 (2025-02-27)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/descarteslabs/hedgewise-sdk-python/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** api update ([c8c2924](https://github.com/descarteslabs/hedgewise-sdk-python/commit/c8c2924cf05e94aba74193e386db90e208f68bd4))


### Chores

* go live ([#1](https://github.com/descarteslabs/hedgewise-sdk-python/issues/1)) ([7db5a4b](https://github.com/descarteslabs/hedgewise-sdk-python/commit/7db5a4b0721e7babbdc14ee3a58ba35c1f64d15f))
* update SDK settings ([#3](https://github.com/descarteslabs/hedgewise-sdk-python/issues/3)) ([0d26126](https://github.com/descarteslabs/hedgewise-sdk-python/commit/0d261266fb96264bf4ca9910ee793316fcb5c3f3))
